@@ -8,6 +8,7 @@
 #' pool$content <- sample(1:3, n_items, replace=TRUE)
 #' pool$time <- round(rlnorm(n_items, log(60), .2))
 #' pool$group <- sort(sample(1:round(n_items/3), n_items, replace=TRUE))
+#' pool <- list('3pl'=pool)
 #'
 #' ## ex. 1: four 10-item forms, maximize b parameter
 #' x <- ata(pool, 4, test_len=10, max_use=1)
@@ -25,15 +26,15 @@
 #' with(x$items$'3pl', table(form))
 #'
 #' ## ex. 3: two 10-item forms, mean(b)=0, sd(b)=1
-#' ## content = (3, 3, 4), avg. time = 58--62 seconds
+#' ## content = (3, 3, 4), avg. time = 55--65 seconds
 #' constr <- data.frame(name='content',level=1:3, min=c(3,3,4), max=c(3,3,4), stringsAsFactors=FALSE)
-#' constr <- rbind(constr, c('time', NA, 58*10, 62*10))
+#' constr <- rbind(constr, c('time', NA, 55*10, 65*10))
 #' x <- ata(pool, 2, test_len=10, max_use=1)
-#' x <- ata_absolute_objective(x, pool$b, 0*10)
-#' x <- ata_absolute_objective(x, (pool$b-0)^2, 1*10)
+#' x <- ata_absolute_objective(x, pool$'3pl'$b, target=0*10)
+#' x <- ata_absolute_objective(x, (pool$'3pl'$b-0)^2, target=1*10)
 #' for(i in 1:nrow(constr))
 #'   x <- with(constr, ata_constraint(x, name[i], min[i], max[i], level=level[i]))
-#' x <- ata_solve(x, time_limit=5)
+#' x <- ata_solve(x)
 #' with(x$items$'3pl', aggregate(b, by=list(form=form), mean))
 #' with(x$items$'3pl', aggregate(b, by=list(form=form), sd))
 #' with(x$items$'3pl', aggregate(time, by=list(form=form), mean))
@@ -65,12 +66,8 @@ ata <- function(pool, n_forms=1, test_len=NULL, max_use=NULL, ...){
 
   opts <- list(...)
   # scaling constants
-  if(is.null(opts$D_3pl))
-    opts$D_3pl <- 1.702
-  if(is.null(opts$D_gpcm))
-    opts$D_gpcm <- 1.702
-  if(is.null(opts$D_grm))
-    opts$D_grm <- 1.702
+  if(is.null(opts$D))
+    opts$D <- 1.702
 
   # combinations of unqiue and common items in each form
   form_map <- ata_form_map(n_forms, opts)
@@ -308,7 +305,7 @@ ata_constraint <- function(x, coef, min=NA, max=NA, level=NULL, forms=NULL, coll
     coef <- aggregate(coef, by=list(group=unlist(x$groups)), sum, na.rm=TRUE)[, -1]
   } else if(is.character(coef) && length(coef) == 1) {
     coef <- Map(function(x, g) {
-      if(nrow(x) == 0)
+      if(is.null(x))
         return(numeric(0))
       if(!coef %in% colnames(x))
         return(rep(0, length(unique(g))))
@@ -440,7 +437,7 @@ ata_item_fix <- function(x, items, min=NA, max=NA, forms){
 #' @rdname ata
 #' @description \code{ata_solve} solves the MIP model
 #' @param solver use 'lpsolve' for lp_solve 5.5 or 'glpk' for GLPK
-#' @param item_format the format of the results: use \code{'form'} to organize results in a list of forms,
+#' @param return_format the format of the results: use \code{'form'} to organize results in a list of forms,
 #' \code{'model'} to organize results in a list of models, use \code{'simple'} to organize results in
 #' data.frame after removing item paraemters.
 #' @param silent \code{TRUE} to mute solution information
@@ -458,7 +455,7 @@ ata_item_fix <- function(x, items, min=NA, max=NA, forms){
 #' function, \code{result} the assembly results in a binary matrix, and
 #' \code{items} the assembled items
 #' @export
-ata_solve <- function(x, solver=c('lpsolve', 'glpk'), item_format=c('model', 'form', 'simple'), silent=FALSE, time_limit=10, message=FALSE, ...) {
+ata_solve <- function(x, solver=c('lpsolve', 'glpk'), return_format=c('model', 'form', 'simple'), silent=FALSE, time_limit=10, message=FALSE, ...) {
   if(class(x) != "ata")
     stop("Not an 'ata' object")
 
@@ -470,6 +467,8 @@ ata_solve <- function(x, solver=c('lpsolve', 'glpk'), item_format=c('model', 'fo
   x$status <- rs$status
   x$optimum <- rs$optimum
   x$obj_vars <- rs$obj_vars
+  x$start_time <- rs$start_time
+  x$solve_time <- rs$solve_time
 
   if(all(rs$result == 0)) {
     x$result <- x$items <- NULL
@@ -480,10 +479,10 @@ ata_solve <- function(x, solver=c('lpsolve', 'glpk'), item_format=c('model', 'fo
       cat(rs$status, ', optimum: ', round(rs$optimum, 3), ' (', paste(round(rs$obj_vars, 3), collapse=', '), ')\n', sep='')
     x$result <- rs$result
     x$items <- ata_extract_items(x)
-    item_format <- match.arg(item_format, item_format)
-    if(item_format %in% c('model', 'simple'))
+    return_format <- match.arg(return_format, return_format)
+    if(return_format %in% c('model', 'simple'))
       x$items <- ata_results_to_model(x$items)
-    if(item_format == 'simple')
+    if(return_format == 'simple')
       x$items <- ata_results_to_dataframe(x$items)
   }
 
